@@ -75,7 +75,10 @@ void nact_fill_actions_list (GtkWidget *list)
 				gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height);
 				icon = gdk_pixbuf_new_from_file_at_size (action->icon, width, height, &error);
 				if (error)
+				{
 					icon = NULL;
+					g_error_free (error);
+				}
 			}
 		}
 		gtk_list_store_append (model, &iter);
@@ -89,11 +92,6 @@ void nact_fill_actions_list (GtkWidget *list)
 	nautilus_actions_config_free_actions_list (actions);
 }
 
-void 
-nautilus_actions_display_error (const gchar *msg)
-{
-}
-
 void
 add_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
@@ -136,6 +134,8 @@ duplicate_button_clicked_cb (GtkButton *button, gpointer user_data)
 	GtkTreeIter iter;
 	GtkWidget *nact_actions_list;
 	GtkTreeModel* model;
+	GError* error = NULL;
+	gchar* tmp;
 
 	nact_actions_list = nact_get_glade_widget ("ActionsList");
 
@@ -153,10 +153,18 @@ duplicate_button_clicked_cb (GtkButton *button, gpointer user_data)
 		new_action = nautilus_actions_config_action_dup_new (action);
 		if (new_action) 
 		{
-			if (nautilus_actions_config_add_action (NAUTILUS_ACTIONS_CONFIG (config), new_action))
+			if (nautilus_actions_config_add_action (NAUTILUS_ACTIONS_CONFIG (config), new_action, &error))
 			{
 				nact_fill_actions_list (nact_actions_list);
 			}
+			else
+			{
+				// i18n notes: will be displayed in a dialog
+				tmp = g_strdup_printf (_("Can't duplicate action '%s' !"), action->label);
+				nautilus_actions_display_error (tmp, error->message);
+				g_error_free (error);
+				g_free (tmp);
+			}
 		}
 
 		g_free (uuid);
@@ -276,7 +284,7 @@ init_dialog (void)
 	GtkWidget* nact_edit_button;
 	GladeXML *gui = nact_get_glade_xml_object (GLADE_MAIN_WIDGET);
 	if (!gui) {
-		nautilus_actions_display_error (_("Could not load interface for Nautilus Actions Config Tool"));
+		g_error (_("Could not load interface for Nautilus Actions Config Tool"));
 		exit (1);
 	}
 
