@@ -21,6 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
@@ -42,6 +43,14 @@ GType nautilus_actions_get_type (void)
 	return actions_type;
 }
 
+#ifndef HAVE_NAUTILUS_MENU_PROVIDER_EMIT_ITEMS_UPDATED_SIGNAL
+static void nautilus_menu_provider_emit_items_updated_signal (NautilusMenuProvider *provider)
+{
+	//--> fake function for backward compatibility
+	//-> do nothing
+}
+#endif
+
 static void nautilus_actions_execute (NautilusMenuItem *item, NautilusActionsConfigAction *action)
 {
 	GList *files;
@@ -117,7 +126,6 @@ static NautilusMenuItem *nautilus_actions_create_menu_item (NautilusActionsConfi
 static GList *nautilus_actions_get_file_items (NautilusMenuProvider *provider, GtkWidget *window, GList *files)
 {
 	GList *items = NULL;
-	GSList* config_list;
 	GSList *iter;
 	NautilusMenuItem *item;
 	NautilusActions* self = NAUTILUS_ACTIONS (provider);
@@ -126,8 +134,7 @@ static GList *nautilus_actions_get_file_items (NautilusMenuProvider *provider, G
 
 	if (!self->dispose_has_run)
 	{
-		config_list = nautilus_actions_config_get_actions (NAUTILUS_ACTIONS_CONFIG (self->configs));
-		for (iter = config_list; iter; iter = iter->next)
+		for (iter = self->config_list; iter; iter = iter->next)
 		{
 			/* Foreach configured action, check if we add a menu item */
 			NautilusActionsConfigAction *action = nautilus_actions_config_action_dup ((NautilusActionsConfigAction*)iter->data);
@@ -143,7 +150,6 @@ static GList *nautilus_actions_get_file_items (NautilusMenuProvider *provider, G
 			}
 		}
 
-		nautilus_actions_config_free_actions_list (config_list);
 	}
 	
 	return items;
@@ -176,6 +182,23 @@ static void nautilus_actions_instance_dispose (GObject *obj)
 	}
 }
 
+static void nautilus_actions_action_changed_handler (NautilusActionsConfig* config, 
+																				NautilusActionsConfigAction* action,
+																				gpointer user_data)
+{
+	NautilusActions* self = NAUTILUS_ACTIONS (user_data);
+	
+	g_return_if_fail (NAUTILUS_IS_ACTIONS (self));
+
+	if (!self->dispose_has_run)
+	{
+		nautilus_menu_provider_emit_items_updated_signal (self);
+
+		nautilus_actions_config_free_actions_list (self->config_list);
+		self->config_list = nautilus_actions_config_get_actions (NAUTILUS_ACTIONS_CONFIG (self->configs));
+	}
+}
+
 static void nautilus_actions_instance_finalize (GObject* obj)
 {
 	//NautilusActions* self = NAUTILUS_ACTIONS (obj);
@@ -198,19 +221,19 @@ static void nautilus_actions_instance_init (GTypeInstance *instance, gpointer kl
 	
 	self->configs = NULL;
 	self->configs = nautilus_actions_config_gconf_reader_get ();
+	self->config_list = NULL;
+	self->config_list = nautilus_actions_config_get_actions (NAUTILUS_ACTIONS_CONFIG (self->configs));
 	self->dispose_has_run = FALSE;
 
-	/*
 	g_signal_connect_after (G_OBJECT (self->configs), "action_added",
-									(GCallback)nautilus_actions_action_added_handler,
+									(GCallback)nautilus_actions_action_changed_handler,
 									self);
 	g_signal_connect_after (G_OBJECT (self->configs), "action_changed",
 									(GCallback)nautilus_actions_action_changed_handler,
 									self);
 	g_signal_connect_after (G_OBJECT (self->configs), "action_removed",
-									(GCallback)nautilus_actions_action_removed_handler,
+									(GCallback)nautilus_actions_action_changed_handler,
 									self);
-	*/
 
 	parent_class = g_type_class_peek_parent (klass);
 }
